@@ -1,7 +1,9 @@
-//! Provides a strongly-typed asynchronous Rusty interface to the Google Geocoding API
+//! A strongly-typed (a)synchronous Rusty API for the Google Geocoding API
 //!
 //! ## Synchronous API (Basic)
 //!
+//! The synchronous API is optimized for the ergonomics of common usage.
+//!
 //! You can do a simple look up of coordinates from an address:
 //!
 //! ```
@@ -24,6 +26,10 @@
 //! Note that it is recommended to use WGS84::try_new() as WGS84::new() will panic
 //! with invalid coordinates
 //!
+//! The synchronous API provides the address or coordinates from the API reply.
+//! However, the full reply includes a great deal more information. For access to
+//! the full reply, see the lowlevel asynchronous API.
+//!
 //! ## Synchronous API (Advanced)
 //!
 //! The GeocodeQuery and DegeocodeQuery objects can be used for more complex lookups
@@ -40,15 +46,43 @@
 //!
 //! ## Asynchronous API
 //!
-//! The Connection object can be used to build an asynchronous application
+//! The Connection object provides access to the lowlevel async-based API.
 //!
-//! The official API documentation can be found at:
-//! [https://developers.google.com/maps/documentation/geocoding/intro]
+//! Unlike the synchronous API, these functions provide the full API reply.
+//! You will therefore need to extract the specific information you want.
+//!
+//! These functions are used to implement the Synchronous API described earlier.
+//!
+//! ```
+//! extern crate google_geocoding;
+//! extern crate tokio_core;
+//!
+//! use google_geocoding::Connection;
+//! use tokio_core::reactor::Core;
+//!
+//! const ADDRESS: &str = "1600 Amphitheater Parkway, Mountain View, CA";
+//!
+//! let mut core = Core::new().unwrap();
+//! let core_handle = core.handle();
+//! let geocode_future = Connection::new(&core_handle).geocode(ADDRESS);
+//! let reply = core.run(geocode_future).unwrap();
+//!
+//! for candidate in reply {
+//!     println!("{}: {}", candidate.formatted_address, candidate.geometry.location);
+//! }
+//! ```
+//!
+//! ## Notes
+//!
+//! This is an unofficial library.
+//!
+//! [Official Google Geocoding API](https://developers.google.com/maps/documentation/geocoding/intro])
 #![deny(missing_docs)]
 #[macro_use]
 extern crate failure;
 extern crate futures;
 extern crate itertools;
+#[cfg(test)]
 #[macro_use]
 extern crate log;
 extern crate nav_types;
@@ -1309,8 +1343,6 @@ mod test {
     const ADDRESS: &str = "1600 Amphitheatre Pkwy, Mountain View, CA 94043, USA";
     const COORDINATES: (f64, f64) = (37.42241, -122.08561);
 
-    use strum::IntoEnumIterator;
-
     fn test_print<L>(i_label: L, i_rr: impl Future<Item = Vec<Reply>, Error=Error>) -> impl Future<Item=(),Error=()> 
         where L: Debug + 'static {
         let label = i_label;
